@@ -112,8 +112,11 @@ NumericVector MedicareLevySaptoYear(NumericVector income,
       case 2019:
         out[i] = MedicareLevySingle(ii, 34758, 43449, 0.020, 0.1, sii, ifi, ndi, 48385, 60483, 3406);
         break;
+      case 2020:
+        out[i] = MedicareLevySingle(ii, 35418, 44274, 0.020, 0.1, sii, ifi, ndi, 49304, 61631, 3471);
+        break;
       default:
-        out[i] = MedicareLevySingle(ii, 34758, 43449, 0.020, 0.1, sii, ifi, ndi, 48385, 60483, 3406);
+        out[i] = MedicareLevySingle(ii, 35418, 44274, 0.020, 0.1, sii, ifi, ndi, 49304, 61631, 3471);
       break;
       }
     } else {
@@ -136,8 +139,14 @@ NumericVector MedicareLevySaptoYear(NumericVector income,
       case 2018:
         out[i] = MedicareLevySingle(ii, 21980, 27476, 0.020, 0.1, sii, ifi, ndi, 37089, 45676, 3406);
         break;
-      default:
+      case 2019:
         out[i] = MedicareLevySingle(ii, 21980, 27476, 0.020, 0.1, sii, ifi, ndi, 37089, 45676, 3406);
+        break;
+      case 2020:
+        out[i] = MedicareLevySingle(ii, 22398, 27999, 0.020, 0.1, sii, ifi, ndi, 37794, 47244, 3471);
+        break;
+      default:
+        out[i] = MedicareLevySingle(ii, 22398, 27999, 0.020, 0.1, sii, ifi, ndi, 37794, 47244, 3471);
       break;
       }
     }
